@@ -4,7 +4,7 @@ package Test::Class::Moose::Role::Executor;
 
 use 5.10.0;
 
-our $VERSION = '0.80';
+our $VERSION = '0.81';
 
 use Moose::Role 2.0000;
 use Carp;
@@ -42,6 +42,20 @@ sub runtests {
     $report->_start_benchmark;
     my @test_classes = $self->test_classes;
 
+    my @bad = grep { !$_->isa('Test::Class::Moose') } @test_classes;
+    if (@bad) {
+        my $msg = 'Found the following class';
+        $msg .= 'es' if @bad > 1;
+        $msg
+          .= ' that '
+          . ( @bad > 1 ? 'are'        : 'is' ) . ' not '
+          . ( @bad > 1 ? 'subclasses' : 'a subclass' )
+          . " of Test::Class::Moose: @bad";
+        $msg .= ' (did you load '
+          . ( @bad > 1 ? 'these classes' : 'this class' ) . '?)';
+        die $msg;
+    }
+
     context_do {
         my $ctx = shift;
 
@@ -518,15 +532,19 @@ Test::Class::Moose::Role::Executor - Common code for Runner classes
 
 =head1 VERSION
 
-version 0.80
+version 0.81
 
 =for Pod::Coverage runtests test_classes
 
 =head1 SUPPORT
 
-Bugs may be submitted through L<https://github.com/test-class-moose/test-class-moose/issues>.
+Bugs may be submitted at L<https://github.com/test-class-moose/test-class-moose/issues>.
 
-I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for Test-Class-Moose can be found at L<https://github.com/test-class-moose/test-class-moose>.
 
 =head1 AUTHORS
 
@@ -544,9 +562,12 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 - 2016 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2017 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
